# MusicBrainz OAuth2 workflow for your application

<p>
  <a href="https://pypi.org/project/mboauth2/">
    <img src="https://img.shields.io/pypi/v/mboauth2?color=purple" alt="Stable Version">
  </a>
  <a href="https://pypistats.org/packages/mboauth2">
    <img src="https://img.shields.io/pypi/dm/mboauth2?color=blue" alt="Downloads">
  </a>
  <a href="https://github.com/Dr-Blank/mboauth2/actions">
    <img src="https://github.com/Dr-Blank/mboauth2/actions/workflows/tests.yaml/badge.svg" alt="Test">
  </a>
  <a href="https://codecov.io/gh/Dr-Blank/mboauth2" > 
    <img src="https://codecov.io/gh/Dr-Blank/mboauth2/graph/badge.svg"/> 
  </a>
  <a href='https://mboauth2.readthedocs.io/en/latest/?badge=latest'>
    <img src='https://readthedocs.org/projects/mboauth2/badge/?version=latest' alt='Documentation Status' />
  </a>
  <a href="https://github.com/psf/black">
    <img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Code style: black">
  </a>
  <a href="https://mypy-lang.org/">
    <img src="https://www.mypy-lang.org/static/mypy_badge.svg" alt="Checked with mypy">
  </a>
</p>

provides a simple way to generate a url for your application to redirect the user to, and a way to get the access token from the callback url.

get your client id and secret from https://musicbrainz.org/account/applications

redirect url must match the url you set in your application

see documentation for examples
